package cn.estsh.i3plus.pojo.aps.bean;

import cn.estsh.i3plus.pojo.aps.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.aps.annotation.RippleAnnotation;
import cn.estsh.i3plus.pojo.aps.common.BaseCode;
import cn.estsh.i3plus.pojo.aps.common.BeanRelation;
import cn.estsh.i3plus.pojo.aps.enums.MATERIAL_TYPE;
import cn.estsh.i3plus.pojo.aps.enums.PREPARE_TYPE;
import cn.estsh.i3plus.pojo.aps.enums.REPLENISHMENT_TYPE;
import cn.estsh.i3plus.pojo.aps.holders.EMaterial;
import com.fasterxml.jackson.annotation.JsonBackReference;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.List;

/**
 * @Description :物料
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-09-17
 * @Modify:
 **/
@Data
@Entity
@Table(name = "APS_MATERIAL")
@Api("物料")
public class Material extends BaseCode {
    @Column(name="TYPE")
    @ApiParam(value ="类型")
    @FieldAnnotation(defaultValue = "PRODUCT")
    private MATERIAL_TYPE type;

    @Column(name="PREPARE_TYPE")
    @ApiParam(value ="备料类型")
    @FieldAnnotation(defaultValue = "SELF_MAKE")
    private PREPARE_TYPE prepareType;

    @Column(name="REPL_TYPE")
    @ApiParam(value ="补充类型")
    private REPLENISHMENT_TYPE replType;

    @Column(name="PURCHASE_LEAD_TIME")
    @ApiParam(value ="采购提前期")
    private String purchaseLeadTime;

    @Column(name="MANUF_LEAD_TIME")
    @ApiParam(value ="制造提前期")
    private String manufLeadTime;

    @Column(name="SHIPMENT_LEAD_TIME")
    @ApiParam(value ="配送提前期")
    private String shipmentLeadTime;

    @Column(name="UNIT_PURCHASE")
    @ApiParam(value ="单位采购量")
    private Integer unitPurchase;

    @Column(name="UNIT_MANUF")
    @ApiParam(value ="单位制造量")
    private Integer unitManuf;

    @Column(name="UNIT_SHIPMENT")
    @ApiParam(value ="单位配送量")
    private Integer unitShipment;

    @Column(name="LEVEL")
    @ApiParam(value ="低阶码")
    @RippleAnnotation(dependence = {"OperOutputs.Operation.ProductRouting.Material"}, method = "calcLevel")
    @FieldAnnotation(modify = false)
    private Integer level;

    @Column(name="IS_AUTO_FIX_PEGGING")
    @ApiParam(value ="自动补充标识")
    @FieldAnnotation(defaultValue = "true")
    private Boolean autoFixPegging;

    @Column(name="MAX_PRODUCT_BATCH")
    @ApiParam(value ="最大制造批量")
    private Double maxProductBatch;

    @Column(name="MIN_PRODUCT_BATCH")
    @ApiParam(value ="最小制造批量")
    @FieldAnnotation(defaultValue = "0.0")
    private Double minProductBatch;

    @Column(name="UNIT_PRODUCT_BATCH")
    @ApiParam(value ="制造批量单位")
    private Double UnitProductBatch;

    @Column(name="MAX_PUR_BATCH")
    @ApiParam(value ="最大采购批量")
    private Double maxPurBatch;

    @Column(name="MIN_PUR_BATCH")
    @ApiParam(value ="最小采购批量")
    private Double minPurBatch;

    @Column(name="UNIT_PUR_BATCH")
    @ApiParam(value ="采购批量单位")
    private Double unitPurBatch;

    @Column(name="MIN_STOCK_COUNT")
    @ApiParam(value ="最小库存数量")
    private Double minStockCount;

    @Column(name="SAFE_STOCK_COUNT")
    @ApiParam(value ="安全库存数量")
    private Double safeStockCount;

    @Column(name="MAX_STOCK_COUNT")
    @ApiParam(value ="最大库存数量")
    private Double maxStockCount;

    @Column(name="ORDER_BATCH_PERIOD")
    @ApiParam(value ="订单合并期间")
    private String orderBatchPeriod;

    @JsonBackReference
    public List<ProductRouting> getProductRoutings() {
        return BeanRelation.list(this, EMaterial.ProductRoutings);
    }

    @JsonBackReference
    public List<OperInput> getOperInputs() {
        return BeanRelation.list(this, EMaterial.OperInputs);
    }

    @JsonBackReference
    public List<OperOutput> getOperOutputs() {
        return BeanRelation.list(this, EMaterial.OperOutputs);
    }

    @JsonBackReference
    public List<WorkInput> getWorkInputs() {
        return BeanRelation.list(this, EMaterial.WorkInputs);
    }

    @JsonBackReference
    public List<WorkOutput> getWorkOutputs() {
        return BeanRelation.list(this, EMaterial.WorkOutputs);
    }

    @JsonBackReference
    public List<WorkRelation> getWorkRelations() {
        return BeanRelation.list(this, EMaterial.WorkRelations);
    }

    @JsonBackReference
    public List<BaseOrder> getOrders() {
        return BeanRelation.list(this, EMaterial.Orders);
    }
}
